"""Context processors
==================

cms_enabled
-------------

Lo skeleton di base installa ``jmb.core.context_processors.cms_enabled`` per
personalizzare ``base.html``. Questo aggiunge al context la variabile dei
settings :var:`CMS_ENABLED`

"""

from __future__ import unicode_literals

from django.conf import settings


def admin_theme_less(request):
    return {'ADMIN_THEME_LESS': settings.ADMIN_THEME_LESS}


def cms_enabled(request):
    return {'CMS_ENABLED': settings.CMS_ENABLED}


def settings_in_context(request):
    """
    Return a dictionary of all settings in SETTINGS_IN_CONTEXT list.
    SETTINGS_IN_CONTEXT is a setting that contain the list of settings that are rendered in context.
    To render a setting value in template you must:
        1. crete your setting
        2. add setting name in SETTINGS_IN_CONTEXT list.
    """
    settings_dict = dict()
    if hasattr(settings, 'SETTINGS_IN_CONTEXT'):

        for setting in settings.SETTINGS_IN_CONTEXT:
            if hasattr(settings, setting):
                settings_dict[setting] = getattr(settings, setting)

    return settings_dict
